spacepy.irbempy.get_dtype — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »

# spacepy.irbempy.get_dtype

`spacepy.irbempy.` `get_dtype`(sysaxes)

  will return the coordinate system type as string

  Parameters: | - sysaxes (int) : number according to the irbem, possible values: 0-8
  Returns: | - dtype (str) : coordinate system GDZ, GEO, GSM, GSE, SM, GEI, MAG, SPH, RLL carsph (str) : cartesian or spherical ‘car’, ‘sph’

  See also

  `get_sysaxes`

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »